@@ -30,6 +30,11 @@
 #define ENOCONTEXT	-2
 #define ENODEVICE	-3
 
+struct buffer {
+	void *start;
+	size_t length;
+};
+
 struct FlashlightContext {
 	/* device name */
 	char device_name[15];
@@ -39,6 +44,9 @@ struct FlashlightContext {
 
 	int min_intensity;
 	int max_intensity;
+
+	unsigned int n_buffers;
+	struct buffer *buffers;
 };
 
 typedef struct FlashlightContext FlashlightContext_t;
